Documentation
¶
Index ¶
- Constants
- func ExtendMessagesIndexerChains(instance *indexer.Indexer)
- func PostSetupCustomFunctionChains(instance *indexer.Indexer, dataset *indexer.PostSetupCustomDataset)
- type ConfirmSourceTxsMsg
- type ConfirmSourceTxsParser
- type ConfirmTokenRequestParser
- type ConfirmTokenValueMsg
- type CreateDeployTokenMsg
- type CreateDeployTokenRequestParser
- type CreatePendingTransfersMsg
- type CreatePendingTransfersParser
- type SignBtcCommandsParser
- type SignCommandsMsg
- type SignCommandsParser
- type SignPsbtCommandsParser
Constants ¶
const ( MSG_SCALAR_CHAINS_FILTER string = "^/scalar.chains.v1beta1.*" MSG_SCALAR_CHAINS_CREATE_DEPLOY_TOKEN_REQUEST string = "/scalar.chains.v1beta1.CreateDeployTokenRequest" MSG_SCALAR_CHAINS_CONFIRM_TOKEN_REQUEST string = "/scalar.chains.v1beta1.ConfirmTokenRequest" MSG_SCALAR_CHAINS_SIGN_COMMANDS_REQUEST string = "/scalar.chains.v1beta1.SignCommandsRequest" MSG_SCALAR_CHAINS_SIGN_BTC_COMMANDS_REQUEST string = "/scalar.chains.v1beta1.SignBtcCommandsRequest" MSG_SCALAR_CHAINS_SIGN_PSBT_COMMANDS_REQUEST string = "/scalar.chains.v1beta1.SignPsbtCommandsRequest" MSG_SCALAR_CHAINS_CONFIRM_SOURCE_TXS_REQUEST string = "/scalar.chains.v1beta1.ConfirmSourceTxsRequest" MSG_SCALAR_CHAINS_CREATE_PENDING_TRANSFERS_REQUEST string = "/scalar.chains.v1beta1.CreatePendingTransfersRequest" )
Variables ¶
This section is empty.
Functions ¶
func PostSetupCustomFunctionChains ¶
func PostSetupCustomFunctionChains(instance *indexer.Indexer, dataset *indexer.PostSetupCustomDataset)
Types ¶
type ConfirmSourceTxsMsg ¶
type ConfirmSourceTxsParser ¶
type ConfirmSourceTxsParser struct {
common.BaseMessageParser
}
func (*ConfirmSourceTxsParser) IndexMessage ¶
func (p *ConfirmSourceTxsParser) IndexMessage(dataset *any, db *gorm.DB, message models.Message, messageEvents []parsers.MessageEventWithAttributes, cfg config.IndexConfig) error
func (*ConfirmSourceTxsParser) ParseMessage ¶
func (p *ConfirmSourceTxsParser) ParseMessage(sdkMsg sdkTypes.Msg, messageLog *indexerTxTypes.LogMessage, cfg config.IndexConfig) (*any, error)
type ConfirmTokenRequestParser ¶
type ConfirmTokenRequestParser struct {
common.BaseMessageParser
}
This defines the custom message parser for the call contract approve message type It implements the MessageParser interface
func (*ConfirmTokenRequestParser) IndexMessage ¶
func (p *ConfirmTokenRequestParser) IndexMessage(dataset *any, db *gorm.DB, message models.Message, messageEvents []parsers.MessageEventWithAttributes, cfg config.IndexConfig) error
This method is called during database insertion. It is responsible for storing the parsed data in the database. The gorm db is wrapped in a transaction, so any errors will cause a rollback. Any errors returned will be saved as a parser error in the database as well for later debugging.
func (*ConfirmTokenRequestParser) ParseMessage ¶
func (p *ConfirmTokenRequestParser) ParseMessage(sdkMsg sdkTypes.Msg, messageLog *indexerTxTypes.LogMessage, cfg config.IndexConfig) (*any, error)
type ConfirmTokenValueMsg ¶
type ConfirmTokenValueMsg struct {
Type string `gorm:"type:varchar(128)" json:"type"`
Sender string `gorm:"type:varchar(64)" json:"sender"`
Chain string `gorm:"type:varchar(64)" json:"chain"`
TxID string `gorm:"type:varchar(64)" json:"tx_id"`
AssetChain string `gorm:"type:varchar(64)" json:"asset_chain"`
AssetSymbol string `gorm:"type:varchar(64)" json:"asset_symbol"`
}
type CreateDeployTokenMsg ¶
type CreateDeployTokenMsg struct {
Type string `gorm:"type:varchar(128)" json:"type"`
Sender string `gorm:"type:varchar(64)" json:"sender"`
Chain string `gorm:"type:varchar(64)" json:"chain"`
TokenSymbol string `gorm:"type:varchar(64)" json:"token_symbol"`
AliasedToken string `gorm:"type:varchar(64)" json:"aliased_token"`
Address string `gorm:"type:varchar(64)" json:"address"`
}
type CreateDeployTokenRequestParser ¶
type CreateDeployTokenRequestParser struct {
common.BaseMessageParser
}
func (*CreateDeployTokenRequestParser) IndexMessage ¶
func (p *CreateDeployTokenRequestParser) IndexMessage(dataset *any, db *gorm.DB, message models.Message, messageEvents []parsers.MessageEventWithAttributes, cfg config.IndexConfig) error
func (*CreateDeployTokenRequestParser) ParseMessage ¶
func (p *CreateDeployTokenRequestParser) ParseMessage(sdkMsg stdTypes.Msg, messageLog *txTypes.LogMessage, cfg config.IndexConfig) (*any, error)
type CreatePendingTransfersParser ¶
type CreatePendingTransfersParser struct {
common.BaseMessageParser
}
func (*CreatePendingTransfersParser) IndexMessage ¶
func (p *CreatePendingTransfersParser) IndexMessage(dataset *any, db *gorm.DB, message models.Message, messageEvents []parsers.MessageEventWithAttributes, cfg config.IndexConfig) error
func (*CreatePendingTransfersParser) ParseMessage ¶
func (p *CreatePendingTransfersParser) ParseMessage(sdkMsg sdkTypes.Msg, messageLog *indexerTxTypes.LogMessage, cfg config.IndexConfig) (*any, error)
type SignBtcCommandsParser ¶
type SignBtcCommandsParser struct {
common.BaseMessageParser
}
func (*SignBtcCommandsParser) IndexMessage ¶
func (p *SignBtcCommandsParser) IndexMessage(dataset *any, db *gorm.DB, message models.Message, messageEvents []parsers.MessageEventWithAttributes, cfg config.IndexConfig) error
func (*SignBtcCommandsParser) ParseMessage ¶
func (p *SignBtcCommandsParser) ParseMessage(sdkMsg sdkTypes.Msg, messageLog *indexerTxTypes.LogMessage, cfg config.IndexConfig) (*any, error)
type SignCommandsMsg ¶
type SignCommandsParser ¶
type SignCommandsParser struct {
common.BaseMessageParser
}
func (*SignCommandsParser) IndexMessage ¶
func (p *SignCommandsParser) IndexMessage(dataset *any, db *gorm.DB, message models.Message, messageEvents []parsers.MessageEventWithAttributes, cfg config.IndexConfig) error
func (*SignCommandsParser) ParseMessage ¶
func (p *SignCommandsParser) ParseMessage(sdkMsg sdkTypes.Msg, messageLog *indexerTxTypes.LogMessage, cfg config.IndexConfig) (*any, error)
type SignPsbtCommandsParser ¶
type SignPsbtCommandsParser struct {
common.BaseMessageParser
}
func (*SignPsbtCommandsParser) IndexMessage ¶
func (p *SignPsbtCommandsParser) IndexMessage(dataset *any, db *gorm.DB, message models.Message, messageEvents []parsers.MessageEventWithAttributes, cfg config.IndexConfig) error
func (*SignPsbtCommandsParser) ParseMessage ¶
func (p *SignPsbtCommandsParser) ParseMessage(sdkMsg sdkTypes.Msg, messageLog *indexerTxTypes.LogMessage, cfg config.IndexConfig) (*any, error)
Click to show internal directories.
Click to hide internal directories.